.. _swh-web:

Software Heritage - Web applications
====================================

Web application(s) to browse the archive, for both interactive (HTML UI)
and mechanized (REST API) use


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   developers-info
   uri-scheme-api
   uri-scheme-browse
   uri-scheme-identifiers
   uri-scheme-misc




Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2


* :ref:`routingtable`
